#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.2
id: nonce-1.0.2-4d1212dfb084a803f723eea311d0a719
key: nonce_FigQnEvwdJg64LaWzZF5Ot
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
exposed-modules:
    Crypto.Nonce
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/nonce-1.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/nonce-1.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/nonce-1.0.2
hs-libraries: HSnonce-1.0.2-FigQnEvwdJg64LaWzZF5Ot
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cprng-aes-0.6.1-31f334ac9b899d0af12f1cbac49d2287
    crypto-random-0.0.9-bdb6a693941c8915b178724d04100946
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
